@@ -1,5 +1,5 @@
 #######################################################################
-# TSP - Traveling Salesperson Problem 
+# TSP - Traveling Salesperson Problem
 # Copyrigth (C) 2011 Michael Hahsler and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
@@ -32,19 +32,19 @@ solve_TSP.ATSP <- function(x, method = NULL, control = NULL, ...) {
 
 ## ETSP
 solve_TSP.ETSP <- function(x, method = NULL, control = NULL, ...) {
-  
+
   ## all but concorde and linkern can only do TSP
   m <- pmatch(tolower(method), c("concorde", "linkern"))
-  if(length(m) == 0L || is.na(m)) x <- as.TSP(x) 
-    
+  if(length(m) == 0L || is.na(m)) x <- as.TSP(x)
+
   .solve_TSP(x, method, control, ...)
 }
 
 
 
-## Deal with Inf: punish (-)Inf with max (min) +(-) 2*range 
+## Deal with Inf: punish (-)Inf with max (min) +(-) 2*range
 .replaceInf <- function(x, pInf = NULL, nInf = NULL) {
-  if(any(is.infinite(x))) { 
+  if(any(is.infinite(x))) {
     range_x <- range(x, na.rm = TRUE, finite = TRUE)
     if(is.null(pInf)) pInf <- range_x[2] + 2* diff(range_x)
     if(is.null(nInf)) nInf <- range_x[1] - 2* diff(range_x)
@@ -56,18 +56,18 @@ solve_TSP.ETSP <- function(x, method = NULL, control = NULL, ...) {
 
 ## workhorse
 .solve_TSP <- function(x, method = NULL, control = NULL, ...) {
-    
+
   ## add ... to control
   control <- c(control, list(...))
-  
+
   ## methods
   methods <- c(
     "identity",
     "random",
     "nearest_insertion",
-    "farthest_insertion",     
-    "cheapest_insertion",     
-    "arbitrary_insertion",     
+    "farthest_insertion",
+    "cheapest_insertion",
+    "arbitrary_insertion",
     "nn",
     "repetitive_nn",
     "2-opt", ### deprecated
@@ -75,20 +75,21 @@ solve_TSP.ETSP <- function(x, method = NULL, control = NULL, ...) {
     "concorde",
     "linkern"
   )
-  
+
   ## default is arbitrary_insertion + two_opt
   if(is.null(method)) {
     method <- "arbitrary_insertion"
-    if(is.null(control$two_opt)) control <- c(control, list(two_opt = TRUE))
+    if(is.null(control$two_opt))
+      control <- c(control, list(two_opt = TRUE))
   } else method <- match.arg(tolower(method), methods)
-  
-  
+
+
   ## check for NAs
   if(any(is.na(x))) stop("NAs not allowed!")
-  
+
   ## Inf
   x_ <- .replaceInf(x)
-  
+
   ## work horses
   .solve_TSP_worker <- function() {
     order <- switch(method,
@@ -106,32 +107,32 @@ solve_TSP.ETSP <- function(x, method = NULL, control = NULL, ...) {
       concorde = tsp_concorde(x_, control = control),
       linkern = tsp_linkern(x_, control = control)
     )
-    
+
     ### do refinement two_opt
-    if(!is.null(control$two_opt) && control$two_opt) { 
-      order <- tsp_two_opt(x_, control = list(tour = order))
+    if(!is.null(control$two_opt) && control$two_opt) {
+      order <- tsp_two_opt(x_, control = c(control, list(tour = order)))
       method <- paste(method , "+two_opt", sep = "")
     }
-    
+
     TOUR(order, method=method, tsp=x)
   }
-  
-  ## do rep? 
+
+  ## do rep?
   if(!is.null(control$rep)) n <- control$rep
-  else n <- 1L   
-  
+  else n <- 1L
+
   if(method == "concorde" || method == "linkern") {
     n <- 1L
-    control$two_opt <- NULL ## no two_opt for these! 
+    control$two_opt <- NULL ## no two_opt for these!
   }
   if(method == "repetitive_nn") n <- 1L
 
   if(n==1L) return(.solve_TSP_worker())
-  
+
   #l <- replicate(n, .solve_TSP_worker(), simplify = FALSE)
   l <- foreach(i = 1:n) %dopar% .solve_TSP_worker()
-  
-  
+
+
   l <- l[[which.min(sapply(l, attr, "tour_length"))]]
   attr(l, "method") <- paste(attr(l, "method"), "_rep_", n, sep="")
   return(l)
